@@ -130,19 +130,15 @@ static void button_size_allocated(GtkWidget* button, GtkAllocation* allocation,
 
 static void update_icon(ShowDesktopData* sdd)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkStyleContext *context;
 	GtkStateFlags    state;
 	GtkBorder        padding;
-#else
-	GtkStyle* style;
-#endif
 	int width, height;
 	GdkPixbuf* icon;
 	GdkPixbuf* scaled;
 	int icon_size;
 	GError* error;
-#if !GTK_CHECK_VERSION (3, 19, 0)
+#if !GTK_CHECK_VERSION (3, 20, 0)
 	int focus_width = 0;
 	int focus_pad = 0;
 #endif
@@ -151,11 +147,10 @@ static void update_icon(ShowDesktopData* sdd)
 	if (!sdd->icon_theme)
 		return;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	state = gtk_widget_get_state_flags (sdd->button);
 	context = gtk_widget_get_style_context (sdd->button);
 	gtk_style_context_get_padding (context, state, &padding);
-#if !GTK_CHECK_VERSION (3, 19, 0)
+#if !GTK_CHECK_VERSION (3, 20, 0)
 	gtk_style_context_get_style (context,
 			             "focus-line-width", &focus_width,
 			             "focus-padding", &focus_pad,
@@ -170,28 +165,11 @@ static void update_icon(ShowDesktopData* sdd)
 		thickness = padding.left + padding.right;
 		break;
 	}
-#if GTK_CHECK_VERSION (3, 19, 0)
+#if GTK_CHECK_VERSION (3, 20, 0)
 	icon_size = sdd->size - thickness;
 #else
 	icon_size = sdd->size - 2 * (focus_width + focus_pad) - thickness;
 #endif
-#else
-	gtk_widget_style_get (sdd->button, "focus-line-width", &focus_width, "focus-padding", &focus_pad, NULL);
-
-	style = gtk_widget_get_style(sdd->button);
-
-	switch (sdd->orient)
-	{
-		case GTK_ORIENTATION_HORIZONTAL:
-			thickness = style->ythickness;
-			break;
-		case GTK_ORIENTATION_VERTICAL:
-			thickness = style->xthickness;
-			break;
-	}
-
-	icon_size = sdd->size - 2 * (focus_width + focus_pad) - thickness;
-#endif
 
 	if (icon_size < 22)
 		icon_size = 16;
@@ -409,9 +387,7 @@ gboolean show_desktop_applet_fill(MatePanelApplet* applet)
 	GtkActionGroup* action_group;
 	gchar* ui_path;
 	AtkObject* atk_obj;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkCssProvider *provider;
-#endif
 
 	mate_panel_applet_set_flags(applet, MATE_PANEL_APPLET_EXPAND_MINOR);
 
@@ -441,12 +417,11 @@ gboolean show_desktop_applet_fill(MatePanelApplet* applet)
 	sdd->button = gtk_toggle_button_new ();
 
 	gtk_widget_set_name (sdd->button, "showdesktop-button");
-#if GTK_CHECK_VERSION (3, 0, 0)
-	provider = gtk_css_provider_new ();
+    provider = gtk_css_provider_new ();
 #if GTK_CHECK_VERSION (3, 20, 0)
 	gtk_css_provider_load_from_data (provider,
 					 "#showdesktop-button {\n"
-					 "border-width: 0px; \n" /*a border here causes GTK warnings */
+                     "border-width: 0px; \n" /*a border here causes GTK warnings */
 					 " padding: 0px;\n"
 					 " margin: 0px; }",
 					 -1, NULL);
@@ -467,17 +442,6 @@ gboolean show_desktop_applet_fill(MatePanelApplet* applet)
 					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 					g_object_unref (provider);
 #endif
-#else
-	gtk_rc_parse_string ("\n"
-		"   style \"showdesktop-button-style\"\n"
-		"   {\n"
-		"      GtkWidget::focus-line-width=0\n"
-		"      GtkWidget::focus-padding=0\n"
-		"   }\n"
-		"\n"
-		"    widget \"*.showdesktop-button\" style \"showdesktop-button-style\"\n"
-		"\n");
-#endif
 
 	atk_obj = gtk_widget_get_accessible(sdd->button);
 	atk_object_set_name (atk_obj, _("Show Desktop Button"));
@@ -541,7 +505,7 @@ static void display_about_dialog(GtkAction* action, ShowDesktopData* sdd)
 	/* Translator credits */
 	//const char* translator_credits = _("translator-credits");
 	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2016 MATE developers\n"
+		"Copyright \xc2\xa9 2012-2017 MATE developers\n"
 		"Copyright \xc2\xa9 2011 Perberos\n"
 		"Copyright \xc2\xa9 2002 Red Hat, Inc.";
 
