@@ -1127,12 +1127,11 @@ panel_place_menu_item_create_menu (PanelPlaceMenuItem *place_item)
 	panel_recent_append_documents_menu (places_menu,
 					    place_item->priv->recent_manager);
 /* Fix any failures of compiz/other wm's to communicate with gtk for transparency */
-#if GTK_CHECK_VERSION (3, 0, 0) 
 	GtkWidget *toplevel = gtk_widget_get_toplevel (places_menu);
 	GdkScreen *screen = gtk_widget_get_screen(GTK_WIDGET(toplevel));
 	GdkVisual *visual = gdk_screen_get_rgba_visual(screen);
 	gtk_widget_set_visual(GTK_WIDGET(toplevel), visual); 
-#endif
+
 	return places_menu;
 }
 
